# AUTOGENERATED! DO NOT EDIT! File to edit: ../00_core.ipynb.

# %% auto 0
__all__ = ['say_hello', 'say_bye', 'HelloSayer']

# %% ../00_core.ipynb 3
def say_hello(to):
    "Say hello to somebody"
    return f'Hello {to}!'

# %% ../00_core.ipynb 6
def say_bye(to):
    "Say bye to somebody"
    return f'Bye {to}!'

# %% ../00_core.ipynb 7
class HelloSayer:
    "Say hello to `to` using `say_hello`"
    def __init__(self, to): self.to = to
        
    def say(self):
        "Do the saying"
        return say_hello(self.to)
